[gtk+/touch-for-3.4] scrolledwindow: Only look at direct touches for now



commit 678027ed188ab924c4adcb48ecc72f475e5e7537
Author: Matthias Clasen <mclasen redhat com>
Date:   Fri Feb 24 14:37:06 2012 -0500

    scrolledwindow: Only look at direct touches for now

 gtk/gtkscrolledwindow.c |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)
---
diff --git a/gtk/gtkscrolledwindow.c b/gtk/gtkscrolledwindow.c
index 99a342d..0dc6abd 100644
--- a/gtk/gtkscrolledwindow.c
+++ b/gtk/gtkscrolledwindow.c
@@ -483,7 +483,7 @@ gtk_scrolled_window_class_init (GtkScrolledWindowClass *class)
    * GtkScrolledWindow:kinetic-scrolling:
    *
    * The kinetic scrolling behavior flags. Kinetic scrolling
    * only applies to devices with source %GDK_SOURCE_TOUCH
    *
    * Since: 3.4
    */
@@ -1114,7 +1114,7 @@ gtk_scrolled_window_get_shadow_type (GtkScrolledWindow *scrolled_window)
  * @flags: flags to apply to kinetic scrolling
  *
  * Specifies the kinetic scrolling behavior for @scrolled_window. Kinetic
  * scrolling only applies to devices with source %GDK_SOURCE_TOUCH.
  *
  * Since: 3.4
  **/
@@ -2670,7 +2670,7 @@ gtk_scrolled_window_captured_button_press (GtkWidget *widget,
   source_device = gdk_event_get_source_device (_event);
   source = gdk_device_get_source (source_device);
 
-  if (source != GDK_SOURCE_TOUCH)
+  if (source != GDK_SOURCE_DIRECT_TOUCH)
     return FALSE;
 
   event = (GdkEventButton *)_event;
@@ -483,7 +483,7 @@ gtk_scrolled_window_class_init (GtkScrolledWindowClass *class)
    *
    * The kinetic scrolling behavior flags. Kinetic scrolling
-   * only applies to devices with source %GDK_SOURCE_TOUCH
+   * only applies to devices with source %GDK_SOURCE_DIRECT_TOUCH
    *
    * Since: 3.4
@@ -1114,7 +1114,7 @@ gtk_scrolled_window_get_shadow_type (GtkScrolledWindow *scrolled_window)
  *
  * Specifies the kinetic scrolling behavior for @scrolled_window. Kinetic
- * scrolling only applies to devices with source %GDK_SOURCE_TOUCH.
+ * scrolling only applies to devices with source %GDK_SOURCE_DIRECT_TOUCH.
  *
  * Since: 3.4



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]